@@ -1,6 +1,7 @@
 from __future__ import absolute_import, print_function
 
 import getpass
+import jinja2
 import os
 import pandas as pd
 import random
@@ -22,6 +23,7 @@ from flask_compress import Compress
 from six import PY3
 
 import dtale.global_state as global_state
+import dtale.config as dtale_config
 from dtale import dtale
 from dtale.cli.clickutils import retrieve_meta_info_and_version, setup_logging
 from dtale.utils import (
@@ -32,9 +34,10 @@ from dtale.utils import (
     fix_url_path,
     get_host,
     is_app_root_defined,
+    make_list,
     running_with_flask_debug,
 )
-from dtale.views import DtaleData, head_data_id, is_up, kill, startup
+from dtale.views import DtaleData, head_endpoint, is_up, kill, startup
 
 if PY3:
     import _thread
@@ -90,6 +93,10 @@ class DtaleFlaskTesting(FlaskClient):
         return super(DtaleFlaskTesting, self).get(url_scheme="http", *args, **kwargs)
 
 
+def contains_route(routes, route):
+    return any((r.rule == route.rule and r.endpoint == route.endpoint) for r in routes)
+
+
 class DtaleFlask(Flask):
     """
     Overriding Flask's implementation of
@@ -112,12 +119,15 @@ class DtaleFlask(Flask):
         """
         self.reaper_on = reaper_on
         self.reaper = None
-        self.base_url = url
-        self.shutdown_url = build_shutdown_url(url)
+        self._setup_url_props(url)
         self.port = None
         self.app_root = app_root
         super(DtaleFlask, self).__init__(import_name, *args, **kwargs)
 
+    def _setup_url_props(self, url):
+        self.base_url = url
+        self.shutdown_url = build_shutdown_url(url)
+
     def update_template_context(self, context):
         super(DtaleFlask, self).update_template_context(context)
         if self.app_root is not None:
@@ -130,12 +140,39 @@ class DtaleFlask(Flask):
             return fix_url_path("{}/{}".format(self.app_root, args[0]))
         return url_for(endpoint, *args, **kwargs)
 
+    def _override_routes(self, rule):
+        try:
+            routes_to_remove = [r for r in self.url_map._rules if r.rule == rule]
+            if routes_to_remove:
+                self.url_map._rules = [
+                    r
+                    for r in self.url_map._rules
+                    if not contains_route(routes_to_remove, r)
+                ]
+
+            self.url_map._remap = True
+            self.url_map.update()
+        except BaseException:
+            logger.exception(
+                "Could not override routes, if you're trying to specify a route for '/' then it will be ignored..."
+            )
+
+    def route(self, rule, **options):
+        self._override_routes(rule)
+        return super(DtaleFlask, self).route(rule, **options)
+
     def run(self, *args, **kwargs):
         """
         :param args: Optional arguments to be passed to :meth:`flask:flask.run`
         :param kwargs: Optional keyword arguments to be passed to :meth:`flask:flask.run`
         """
-        self.port = str(kwargs.get("port") or "")
+        port_num = kwargs.get("port")
+        self.port = str(port_num or "")
+        if not self.base_url:
+            host = kwargs.get("host")
+            initialize_process_props(host, port_num)
+            app_url = build_url(self.port, host)
+            self._setup_url_props(app_url)
         if kwargs.get("debug", False):
             self.reaper_on = False
         self.build_reaper()
@@ -212,14 +249,21 @@ class DtaleFlask(Flask):
 
 
 def build_app(
-    url,
-    host=None,
-    reaper_on=True,
-    app_root=None,
+    url=None, reaper_on=True, app_root=None, additional_templates=None, **kwargs
 ):
     """
     Builds :class:`flask:flask.Flask` application encapsulating endpoints for D-Tale's front-end
 
+    :param url: optional parameter which sets the host & root for any internal endpoints (ex: pinging shutdown)
+    :type url: str, optional
+    :param reaper_on: whether to run auto-reaper subprocess
+    :type reaper_on: bool
+    :param app_root: Optional path to prepend to the routes of D-Tale. This is used when making use of
+                     Jupyterhub server proxy
+    :type app_root: str, optional
+    :param additional_templates: path(s) to any other jinja templates you would like to load.  This comes into play if
+                                 you're embedding D-Tale into your own Flask app
+    :type: str, list, optional
     :return: :class:`flask:flask.Flask` application
     :rtype: :class:`dtale.app.DtaleFlask`
     """
@@ -242,20 +286,34 @@ def build_app(
         app.jinja_env.globals["url_for"] = app.url_for
     app.jinja_env.globals["is_app_root_defined"] = is_app_root_defined
 
+    if additional_templates:
+        loaders = [app.jinja_loader]
+        loaders += [
+            jinja2.FileSystemLoader(loc) for loc in make_list(additional_templates)
+        ]
+        my_loader = jinja2.ChoiceLoader(loaders)
+        app.jinja_loader = my_loader
+
     app.register_blueprint(dtale)
 
     compress = Compress()
     compress.init_app(app)
 
+    def _root():
+        return redirect("/dtale/{}".format(head_endpoint()))
+
     @app.route("/")
-    @app.route("/dtale")
     def root():
+        return _root()
+
+    @app.route("/dtale")
+    def dtale_base():
         """
         :class:`flask:flask.Flask` routes which redirect to dtale/main
 
         :return: 302 - flask.redirect('/dtale/main')
         """
-        return redirect("/dtale/main/{}".format(head_data_id()))
+        return _root()
 
     @app.route("/favicon.ico")
     def favicon():
@@ -485,6 +543,8 @@ def find_free_port():
 
 
 def build_startup_url_and_app_root(app_root=None):
+    global ACTIVE_HOST, ACTIVE_PORT, JUPYTER_SERVER_PROXY, USE_COLAB
+
     if USE_COLAB:
         colab_host = use_colab(ACTIVE_PORT)
         if colab_host:
@@ -514,28 +574,7 @@ def use_colab(port):
         return None
 
 
-def show(
-    data=None,
-    host=None,
-    port=None,
-    name=None,
-    debug=False,
-    subprocess=True,
-    data_loader=None,
-    reaper_on=True,
-    open_browser=False,
-    notebook=False,
-    force=False,
-    context_vars=None,
-    ignore_duplicate=False,
-    app_root=None,
-    allow_cell_edits=True,
-    inplace=False,
-    drop_index=False,
-    hide_shutdown=False,
-    github_fork=False,
-    **kwargs
-):
+def show(data=None, data_loader=None, name=None, context_vars=None, **options):
     """
     Entry point for kicking off D-Tale :class:`flask:flask.Flask` process from python process
 
@@ -597,11 +636,12 @@ def show(
 
         ..link displayed in logging can be copied and pasted into any browser
     """
-    global ACTIVE_HOST, ACTIVE_PORT, USE_NGROK, USE_COLAB, JUPYTER_SERVER_PROXY
+    global ACTIVE_HOST, ACTIVE_PORT, USE_NGROK
 
     try:
+        final_options = dtale_config.build_show_options(options)
         logfile, log_level, verbose = map(
-            kwargs.get, ["logfile", "log_level", "verbose"]
+            final_options.get, ["logfile", "log_level", "verbose"]
         )
         setup_logging(logfile, log_level or "info", verbose)
 
@@ -616,28 +656,30 @@ def show(
             ACTIVE_HOST = _run_ngrok()
             ACTIVE_PORT = None
         else:
-            initialize_process_props(host, port, force)
+            initialize_process_props(
+                final_options["host"], final_options["port"], final_options["force"]
+            )
 
         app_url = build_url(ACTIVE_PORT, ACTIVE_HOST)
-        startup_url, final_app_root = build_startup_url_and_app_root(app_root)
+        startup_url, final_app_root = build_startup_url_and_app_root(
+            final_options["app_root"]
+        )
         instance = startup(
             startup_url,
             data=data,
             data_loader=data_loader,
             name=name,
             context_vars=context_vars,
-            ignore_duplicate=ignore_duplicate,
-            allow_cell_edits=allow_cell_edits,
-            inplace=inplace,
-            drop_index=drop_index,
-            hide_shutdown=hide_shutdown,
-            github_fork=github_fork,
+            ignore_duplicate=final_options["ignore_duplicate"],
+            allow_cell_edits=final_options["allow_cell_edits"],
+            inplace=final_options["inplace"],
+            drop_index=final_options["drop_index"],
         )
         is_active = not running_with_flask_debug() and is_up(app_url)
         if is_active:
 
             def _start():
-                if open_browser:
+                if final_options["open_browser"]:
                     instance.open_browser()
 
         else:
@@ -649,17 +691,17 @@ def show(
             def _start():
                 app = build_app(
                     app_url,
-                    reaper_on=reaper_on,
+                    reaper_on=final_options["reaper_on"],
                     host=ACTIVE_HOST,
                     app_root=final_app_root,
                 )
-                if debug and not USE_NGROK:
+                if final_options["debug"] and not USE_NGROK:
                     app.jinja_env.auto_reload = True
                     app.config["TEMPLATES_AUTO_RELOAD"] = True
                 else:
                     getLogger("werkzeug").setLevel(LOG_ERROR)
 
-                if open_browser:
+                if final_options["open_browser"]:
                     instance.open_browser()
 
                 # hide banner message in production environments
@@ -671,16 +713,19 @@ def show(
                     app.run(threaded=True)
                 else:
                     app.run(
-                        host="0.0.0.0", port=ACTIVE_PORT, debug=debug, threaded=True
+                        host="0.0.0.0",
+                        port=ACTIVE_PORT,
+                        debug=final_options["debug"],
+                        threaded=True,
                     )
 
-        if subprocess:
+        if final_options["subprocess"]:
             if is_active:
                 _start()
             else:
                 _thread.start_new_thread(_start, ())
 
-            if notebook:
+            if final_options["notebook"]:
                 instance.notebook()
         else:
             logger.info("D-Tale started at: {}".format(app_url))
