@@ -1,11 +1,22 @@
 import random
 import string
+import strsimpy
+import struct
 import time
 
 import numpy as np
 import pandas as pd
 from scipy.stats import mstats
 from six import string_types
+from sklearn.preprocessing import (
+    LabelEncoder,
+    OrdinalEncoder,
+    PowerTransformer,
+    QuantileTransformer,
+    RobustScaler,
+)
+from sklearn.feature_extraction import FeatureHasher
+from strsimpy.jaro_winkler import JaroWinkler
 
 import dtale.global_state as global_state
 from dtale.utils import classify_type
@@ -32,6 +43,12 @@ class ColumnBuilder(object):
             self.builder = WinsorizeColumnBuilder(name, cfg)
         elif column_type == "zscore_normalize":
             self.builder = ZScoreNormalizeColumnBuilder(name, cfg)
+        elif column_type == "similarity":
+            self.builder = SimilarityColumnBuilder(name, cfg)
+        elif column_type == "standardize":
+            self.builder = StandardizedColumnBuilder(name, cfg)
+        elif column_type == "encoder":
+            self.builder = EncoderColumnBuilder(name, cfg)
         else:
             raise NotImplementedError(
                 "'{}' column builder not implemented yet!".format(column_type)
@@ -370,6 +387,10 @@ class RandomColumnBuilder(object):
         ).format(low=low, high=high, name=self.name)
 
 
+def float_to_hex(f):
+    return hex(struct.unpack("<I", struct.pack("<f", f))[0])
+
+
 class TypeConversionColumnBuilder(object):
     def __init__(self, name, cfg):
         self.name = name
@@ -434,8 +455,12 @@ class TypeConversionColumnBuilder(object):
                 return pd.Series(
                     pd.to_datetime(s, unit=unit), name=self.name, index=s.index
                 )
+            elif to_type == "hex":
+                return pd.Series(s.apply(float_to_hex), name=self.name, index=s.index)
             return pd.Series(s.astype(to_type), name=self.name, index=s.index)
         elif classifier == "F":  # str, int
+            if to_type == "hex":
+                return pd.Series(s.apply(float_to_hex), name=self.name, index=s.index)
             return pd.Series(s.astype(to_type), name=self.name, index=s.index)
         elif classifier == "D":  # str, int
             if to_type == "int":
@@ -460,6 +485,14 @@ class TypeConversionColumnBuilder(object):
             "data type conversion not supported for dtype: {}".format(from_type)
         )
 
+    def build_hex_code(self, s):
+        return (
+            "import struct\n\n"
+            "def float_to_hex(f):\n"
+            "\treturn hex(struct.unpack('<I', struct.pack('<f', f))[0])\n\n"
+            "pd.Series({s}.apply(float_to_hex), name='{name}', index={s}.index)"
+        ).format(s=s, name=self.name)
+
     def build_inner_code(self):
         col, from_type, to_type = (self.cfg.get(p) for p in ["col", "from", "to"])
         s = "df['{col}']".format(col=col)
@@ -500,7 +533,7 @@ class TypeConversionColumnBuilder(object):
                 return "pd.Series({s}.astype({to_type}), name='{name}', index={s}.index)".format(
                     s=s, to_type=to_type, name=self.name
                 )
-        elif classifier == "I":  # date, float, category, str, bool
+        elif classifier == "I":  # date, float, category, str, bool, hex
             if to_type == "date":
                 unit = self.cfg.get("unit") or "D"
                 if unit == "YYYYMMDD":
@@ -511,10 +544,14 @@ class TypeConversionColumnBuilder(object):
                 return "pd.Series(pd.to_datetime({s}, unit='{unit}'), name='{name}', index={s}.index)".format(
                     s=s, name=self.name, unit=unit
                 )
+            elif to_type == "hex":
+                return self.build_hex_code(s)
             return "pd.Series({s}.astype('{to_type}'), name='{name}', index={s}.index)".format(
                 s=s, to_type=to_type, name=self.name
             )
-        elif classifier == "F":  # str, int
+        elif classifier == "F":  # str, int, hex
+            if to_type == "hex":
+                return self.build_hex_code(s)
             return "pd.Series(s.astype('{to_type}'), name='{name}', index={s}.index)".format(
                 s=s, to_type=to_type, name=self.name
             )
@@ -654,3 +691,209 @@ class ZScoreNormalizeColumnBuilder(object):
             "\t(data['{col}'] - data['{col}'].mean()) / data['{col}'].std(ddof=0), index=data.index, name='{name}'\n"
             ")"
         ).format(name=self.name, col=col)
+
+
+class SimilarityNormalizeWrapper(object):
+    def __init__(self, algo):
+        self.algo = algo
+
+    def distance(self, s0, s1):
+        if s0 is None:
+            raise TypeError("Argument s0 is NoneType.")
+        if s1 is None:
+            raise TypeError("Argument s1 is NoneType.")
+        if s0 == s1:
+            return 0.0
+        m_len = max(len(s0), len(s1))
+        if m_len == 0:
+            return 0.0
+        return self.algo.distance(s0, s1) / m_len
+
+
+class SimilarityColumnBuilder(object):
+    def __init__(self, name, cfg):
+        self.name = name
+        self.cfg = cfg
+
+    def build_column(self, data):
+        left_col, right_col, algo = (self.cfg.get(p) for p in ["left", "right", "algo"])
+        normalized = self.cfg.get("normalized", False)
+        if algo == "levenshtein":
+            if normalized:
+                similarity = strsimpy.normalized_levenshtein.NormalizedLevenshtein()
+            else:
+                similarity = strsimpy.levenshtein.Levenshtein()
+        elif algo == "damerau-leveneshtein":
+            similarity = strsimpy.damerau.Damerau()
+            if normalized:
+                similarity = SimilarityNormalizeWrapper(similarity)
+        elif algo == "jaro-winkler":
+            similarity = JaroWinkler()
+        elif algo == "jaccard":
+            similarity = strsimpy.jaccard.Jaccard(int(self.cfg.get("k", 3)))
+            if normalized:
+                similarity = SimilarityNormalizeWrapper(similarity)
+        distances = (
+            data[[left_col, right_col]]
+            .fillna("")
+            .apply(lambda rec: similarity.distance(*rec), axis=1)
+        )
+        return pd.Series(distances, index=data.index, name=self.name)
+
+    def build_code(self):
+        left_col, right_col, algo = (self.cfg.get(p) for p in ["left", "right", "algo"])
+        normalized = self.cfg.get("normalized", False)
+        import_str = ""
+        if algo == "levenshtein":
+            import_str = (
+                "\nfrom strsimpy.levenshtein import Levenshtein\n"
+                "similarity = Levenshtein()"
+            )
+            if normalized:
+                import_str = (
+                    "\nfrom strsimpy.normalized_levenshtein import NormalizedLevenshtein\n"
+                    "similarity = NormalizedLevenshtein()"
+                )
+        elif algo == "damerau-leveneshtein":
+            base_import = "from strsimpy.damerau import Damerau\nsimilarity = Damerau()"
+            if normalized:
+                import_str = (
+                    "\nfrom dtale.column_builders import SimilarityNormalizeWrapper\n"
+                    "{base_import}\nsimilarity = SimilarityNormalizeWrapper(similarity)"
+                ).format(base_import=base_import)
+            else:
+                import_str = "\n{}".format(base_import)
+        elif algo == "jaro-winkler":
+            import_str = (
+                "\nfrom strsimpy.jaro_winkler import JaroWinkler\n"
+                "similarity = JaroWinkler()"
+            )
+        elif algo == "jaccard":
+            base_import = (
+                "\nfrom strsimpy.jaccard import Jaccard\n" "similarity = Jaccard({k})"
+            ).format(k=str(self.cfg.get("k", "")))
+            if normalized:
+                import_str = (
+                    "\nfrom dtale.column_builders import SimilarityNormalizeWrapper\n"
+                    "{base_import}\nsimilarity = SimilarityNormalizeWrapper(similarity)"
+                ).format(base_import=base_import)
+            else:
+                import_str = "\n{}".format(base_import)
+
+        return (
+            "{import_str}\n"
+            "distances = data[['{l}', '{r}']].fillna('').apply(lambda rec: similarity.distance(*rec))\n"
+            "df.loc[:, '{name}'] = pd.Series(distances, index=data.index, name='{name}')"
+        ).format(name=self.name, l=left_col, r=right_col, import_str=import_str)
+
+
+class StandardizedColumnBuilder(object):
+    def __init__(self, name, cfg):
+        self.name = name
+        self.cfg = cfg
+
+    def build_column(self, data):
+        col, algo = (self.cfg.get(p) for p in ["col", "algo"])
+        if algo == "robust":
+            transformer = RobustScaler()
+        elif algo == "quantile":
+            transformer = QuantileTransformer()
+        elif algo == "power":
+            transformer = PowerTransformer(method="yeo-johnson", standardize=True)
+        standardized = transformer.fit_transform(data[[col]]).reshape(-1)
+        return pd.Series(standardized, index=data.index, name=self.name)
+
+    def build_code(self):
+        col, algo = (self.cfg.get(p) for p in ["col", "algo"])
+        import_str = ""
+        if algo == "robust":
+            import_str = (
+                "\nfrom sklearn.preprocessing import RobustScaler\n"
+                "transformer = RobustScaler()"
+            )
+        elif algo == "quantile":
+            import_str = (
+                "\nfrom sklearn.preprocessing import QuantileTransformer\n"
+                "transformer = QuantileTransformer()"
+            )
+        elif algo == "power":
+            import_str = (
+                "\nfrom sklearn.preprocessing import PowerTransformer\n"
+                "transformer = PowerTransformer(method='yeo-johnson', standardize=True)"
+            )
+
+        return (
+            "{import_str}\n"
+            "standardized = transformer.fit_transform(data[['{col}']]).reshape(-1)\n"
+            "df.loc[:, '{name}'] = pd.Series(standardized, index=data.index, name='{name}')"
+        ).format(name=self.name, col=col, import_str=import_str)
+
+
+class EncoderColumnBuilder(object):
+    def __init__(self, name, cfg):
+        self.name = name
+        self.cfg = cfg
+
+    def build_column(self, data):
+        col, algo = (self.cfg.get(p) for p in ["col", "algo"])
+        if algo == "one_hot":
+            return pd.get_dummies(data, columns=[col], drop_first=True)
+        elif algo == "ordinal":
+            is_nan = data[col].isnull()
+            ordinals = (
+                OrdinalEncoder().fit_transform(data[[col]].astype("str")).reshape(-1)
+            )
+            return pd.Series(ordinals, index=data.index, name=self.name).where(
+                ~is_nan, 0
+            )
+        elif algo == "label":
+            is_nan = data[col].isnull()
+            labels = LabelEncoder().fit_transform(data[col].astype("str"))
+            return pd.Series(labels, index=data.index, name=self.name).where(~is_nan, 0)
+        elif algo == "feature_hasher":
+            n = int(self.cfg.get("n"))
+            features = (
+                FeatureHasher(n_features=n, input_type="string")
+                .transform(data[col].astype("str"))
+                .toarray()
+            )
+            features = pd.DataFrame(features, index=data.index)
+            features.columns = ["{}_{}".format(col, col2) for col2 in features.columns]
+            return features
+        raise NotImplementedError("{} not implemented yet!".format(algo))
+
+    def build_code(self):
+        col, algo = (self.cfg.get(p) for p in ["col", "algo"])
+        if algo == "one_hot":
+            return (
+                "dummies = pd.get_dummies(df, columns=['{col}'], drop_first=True)\n"
+                "for i in range(len(dummies.columns)):\n"
+                "\tnew_col = dummies.iloc[:, i]\n"
+                "\tdf.loc[:, str(new_col.name)] = new_col"
+            ).format(col=col)
+        elif algo == "ordinal":
+            return (
+                "\nfrom sklearn.preprocessing import OrdinalEncoder\n"
+                "is_nan = df['{col}'].isnull()\n"
+                "ordinals = OrdinalEncoder().fit_transform(df[['{col}']]).reshape(-1)\n"
+                "df.loc[:, '{name}'] = pd.Series(ordinals, index=df.index, name='{name}').where(~is_nan, 0)"
+            ).format(col=col, name=self.name)
+        elif algo == "label":
+            return (
+                "\nfrom sklearn.preprocessing import LabelEncoder\n"
+                "is_nan = df['{col}'].isnull()"
+                "labels = OrdinalEncoder().fit_transform(df['{col}'])\n"
+                "df.loc[:, '{name}'] = pd.Series(labels, index=df.index, name='{name}').where(~is_nan, 0)"
+            ).format(col=col, name=self.name)
+        elif algo == "feature_hasher":
+            return (
+                "\nfrom sklearn.feature_extraction import FeatureHasher\n"
+                "hasher = FeatureHasher(n_features={n}, input_type='string')\n"
+                "features = hasher.transform(data['{col}'].astype('str')).toarray()\n"
+                "features = pd.DataFrame(features, index=df.index)\n"
+                "features.columns = ['{col}_' + col2 for col2 in features.columns]\n"
+                "for i in range(len(features.columns)):\n"
+                "\tnew_col = features.iloc[:, i]\n"
+                "\tdf.loc[:, str(new_col.name)] = new_col"
+            ).format(n=self.cfg.get("n"), col=col)
+        return ""
