@@ -21,11 +21,11 @@ from dtale.dash_application.layout.utils import (
     FREQS,
     FREQ_LABELS,
 )
+from dtale.query import inner_build_query
 from dtale.utils import (
     ChartBuildingError,
     classify_type,
     get_dtypes,
-    inner_build_query,
     is_app_root_defined,
     make_list,
 )
@@ -93,7 +93,6 @@ def base_layout(app_root, **kwargs):
                         const pathSegs = window.location.pathname.split('/');
                         const dataId = pathSegs[pathSegs.length - 1];
                         const backToData = () => window.open('{app_root}/dtale/main/' + dataId);
-                        const goToLegacy = () => location.replace('{app_root}/dtale/popup/charts/' + dataId);
                     </script>
                     {renderer}
                     {css}
