@@ -41,7 +41,8 @@ from dtale.dash_application.layout.layout import (
 )
 from dtale.dash_application.layout.utils import show_style
 from dtale.dash_application.utils import get_data_id
-from dtale.utils import dict_merge, is_app_root_defined, make_list, run_query
+from dtale.query import run_query
+from dtale.utils import dict_merge, is_app_root_defined, make_list
 
 logger = getLogger(__name__)
 
@@ -86,7 +87,6 @@ class DtaleDash(dash.Dash):
         super(DtaleDash, self).__init__(*args, **kwargs)
 
     def interpolate_index(self, **kwargs):
-        print(kwargs)
         return base_layout(self.server.config.get("APPLICATION_ROOT"), **kwargs)
 
 
@@ -101,7 +101,7 @@ def add_dash(server):
     """
 
     dash_app = DtaleDash(
-        server=server, routes_pathname_prefix="/charts/", eager_loading=True
+        server=server, routes_pathname_prefix="/dtale/charts/", eager_loading=True
     )
 
     # Since we're adding callbacks to elements that don't exist in the app.layout,
