@@ -15,6 +15,11 @@ SETTINGS = {}
 METADATA = {}
 CONTEXT_VARIABLES = {}
 HISTORY = {}
+APP_SETTINGS = {
+    "theme": "light",
+    "github_fork": False,
+    "hide_shutdown": False,
+}
 
 
 def drop_punctuation(val):
@@ -105,6 +110,12 @@ def get_history(data_id=None):
     return HISTORY.get(data_id)
 
 
+def get_app_settings():
+    global APP_SETTINGS
+
+    return APP_SETTINGS
+
+
 def set_data(data_id, val):
     global DATA
 
@@ -153,6 +164,13 @@ def set_history(data_id, val):
     HISTORY[data_id] = val
 
 
+def set_app_settings(settings):
+    global APP_SETTINGS
+
+    for prop, val in settings.items():
+        APP_SETTINGS[prop] = val
+
+
 def cleanup(data_id=None):
     """
     Helper function for cleanup up state related to a D-Tale process with a specific port
@@ -263,7 +281,7 @@ def use_store(store_class, create_store):
         old_store.clear()
         return new_store
 
-    global DATA, DTYPES, SETTINGS, METADATA, CONTEXT_VARIABLES, HISTORY
+    global DATA, DTYPES, SETTINGS, METADATA, CONTEXT_VARIABLES, HISTORY, APP_SETTINGS
 
     DATA = convert(DATA, "DATA")
     DTYPES = convert(DTYPES, "DTYPES")
@@ -271,6 +289,7 @@ def use_store(store_class, create_store):
     METADATA = convert(METADATA, "METADATA")
     CONTEXT_VARIABLES = convert(CONTEXT_VARIABLES, "CONTEXT_VARIABLES")
     HISTORY = convert(HISTORY, "HISTORY")
+    APP_SETTINGS = convert(APP_SETTINGS, "APP_SETTINGS")
 
 
 def use_default_store():
@@ -347,6 +366,10 @@ def use_shelve_store(directory):
         def to_dict(self):
             return dict(self.db)
 
+        @read
+        def items(self):
+            return self.to_dict().items()
+
         @read
         def __len__(self):
             return len(self.db)
@@ -393,6 +416,9 @@ def use_redis_store(directory, *args, **kwargs):
         def to_dict(self):
             return {k.decode("utf-8"): self.get(k) for k in self.keys()}
 
+        def items(self):
+            return self.to_dict().items()
+
         def __len__(self):
             return len(self.keys())
 
